/*******************************************************************************
data2matlab_v3.do

Estimates the p_t for the dynamic model and formats the data for that purpose.
	Uses 9 stacked DRGs.
	Includes discharges to home care as well as discharges to nursing facilities
	
*******************************************************************************/
clear all
set more off
cap log close
set maxvar 30000
set matsize 11000

cd /net/storage-01/econ/research/jr139/LTCH/
log using work/datawork/data2matlab_v2.txt,replace text



/******************Switches**************************/

local payoff_and_other = 1
local costs = 1


/****************************************************************************
		Payoffs and other data (discharges and ownership)
****************************************************************************/
if `payoff_and_other'==1 {

use data/MEDPAR_POS_ALL.dta
gen LOS = length_of_stay


/**Dropping 2002 observations**/
drop if fyear==2002

/**Dropping observations from 2014 and 2015**/
keep if fyear<2014

/** Generating patient id **/
gen pat_id = _n


drop if cDRG==0

/**Filling in some missing data gaps using the mode by hospital.  This is a 
	temporary fix--I'll need to find the actual data at some point.  **/
sort prov_id fyear
by prov_id: egen mode_msa = mode(prov_msa)
by prov_id: egen mode_fp  = mode(prov_fp)
by prov_id: egen mode_hwh = mode(aha_hwh)
replace prov_msa = mode_msa if prov_msa==""
replace prov_msa = mode_msa if prov_msa=="."
replace prov_fp = mode_fp if prov_fp==.
replace aha_hwh = mode_hwh if aha_hwh==.

destring(prov_id),gen(numprov_id)
destring(prov_msa),gen(numprov_msa)

/**Keeping discharges to home care or to nursing facility care**/
keep if disch_home | disch_snf | disch_othnf

/**Keeping only claims with positive Medicare payments**/
keep if drg_price>0

/**Full payment**/
gen fullpayment = ((sfr)*lrs*wage_ind + sfr*(1-lrs))*weight
/*Filling in missing fullpayments with year*DRC mean*/
sort fyear cDRG
by fyear cDRG: egen temp = mean(fullpayment)
replace fullpayment=temp if fullpayment==.

gen temp_diff = fullpayment-drg_price

disp "Comparing constructed full payment with DRG price on magic day"
sum temp_diff if LOS>sso_thresh & LOS<sso_thresh+1,d
drop temp_diff

/**Per-diem payment**/
gen perdiem = fullpayment/geo_mean*LOS*1.2

/********SSO Payments********/
/**Identifying observations that are in the tails of LOS distributions within
	cDRG and Year**/
	
sort LOS fyear cDRG
by LOS fyear cDRG: gen first = _n==1
by LOS fyear cDRG: egen p95 = pctile(drg_price),p(95)
by LOS fyear cDRG: egen p5  = pctile(drg_price),p(5)



/*
reg drg_price c.(LOS)#fyear#cDRG c.LOS#fyear#numprov_id ///
		if LOS<sso_thresh & drg_price>p5 & drg_price<p95,noconst

preserve
sort fyear prov_id pat_id
gen T = 45
expand T
sort pat_id LOS
by pat_id: gen day = _n
replace LOS = day
predict pay,xb
sum pay if day==1,d
restore
	
*/

reg drg_price c.LOS#fyear#(cDRG prov_fp##aha_hwh numprov_msa) ///
		if LOS<sso_thresh & drg_price>p5 & drg_price<p95,noconst

/*preserve*/
sort fyear cDRG prov_id pat_id
gen T = 45
expand T
sort pat_id LOS
by pat_id: gen day = _n
replace LOS = day
predict pay,xb
drop T
sum pay if day==1,d

replace pay = fullpayment if day>sso_thresh


sort pat_id day
tsset pat_id day
gen p_t = s.pay
by pat_id: replace p_t = pay if _n==1 & p_t==.

order pat_id day LOS fyear pay p_t fullpayment sso_thresh

/**Organizing data for export**/
gen discharge = (length_of_stay==day)
gen est_cumulative_payoff = pay
gen magic_day = (ceil(sso_thresh)==day)

order pat_id prov_id fyear cDRG day LOS discharge magic_day ///
	est_cumulative_payoff p_t fullpayment prov_fp prov_nfp prov_govt  ///
	prov_msa kindred select disch_home male white black asian hisp ///
	natam rcoth agegrp est_tot_costs est_cov_costs sso_thresh drg_price preS ///
	day_of_admission source_of_admission type_of_admission cbsa_ltch
	
save data/daily_payoffs_stackedDRG_long.dta,replace

keep pat_id prov_id fyear cDRG day discharge magic day p_t kindred select ///
	prov_fp geo_mean fullpayment aha_hwh preS preK postS postK ///
	sso_thresh day_of_admission black agegrp source_of_admission ///
	type_of_admission male length_of_stay cbsa_ltch
	
replace p_t = 0 if p_t==.
    
drop if prov_fp==. | geo_mean==. | aha_hwh==. | black==. | agegrp==. | male==. | length_of_stay==.    
    
save data/daily_payoffs_stackedDRG_small.dta,replace



/**Outputting estimated payments**/
preserve
sort pat_id day
keep pat_id p_t day
reshape wide p_t,i(pat_id) j(day)
sort pat_id 
drop pat_id 
outsheet p_t1-p_t45 using data/payoffs2matlab_v2.csv,nonames delimiter(",") replace
restore

/** Outputting discharges **/
preserve
sort pat_id day
keep pat_id discharge day
reshape wide discharge,i(pat_id) j(day)
sort pat_id 
drop pat_id 
outsheet discharge1-discharge45 using data/discharges2matlab_v2.csv,noname delimiter(",") replace
restore

/**  Outputting day of week   **/
preserve
sort pat_id day
keep pat_id discharge day day_of_admission
gen temp = .
replace temp = day_of_admission if day==1
replace temp = day_of_admission+day-1 if day>1
gen day_of_week = mod(temp,7)
drop temp
replace day_of_week = 7 if day_of_week==0
sort pat_id day
keep pat_id day_of_week day
reshape wide day_of_week,i(pat_id) j(day)
sort pat_id
drop pat_id
outsheet day_of_week1-day_of_week45 using data/day_of_week2matlab_v2.csv, ///
			nonames delimiter(",") replace
restore

/** Outputting ownership type **/
preserve 
sort pat_id day
gen ind_fp = (prov_fp==1) * (select==0) * (kindred==0)
gen ind_nfp = (prov_fp==0) * (select==0) * (kindred==0)
replace ind_fp =0 if select==1
replace ind_nfp=0 if select==1
replace ind_fp =0 if kindred==1
replace ind_nfp=0 if kindred==1
keep pat_id day ind_nfp ind_fp kindred select
reshape wide ind_nfp ind_fp kindred select,i(pat_id) j(day)
keep pat_id ind_nfp1 ind_fp1 kindred1 select1
order ind_nfp1 ind_fp1 kindred1 select1
sort pat_id
drop pat_id
outsheet ind_nfp1 ind_fp1 kindred1 select1 using data/ownership2matlab_v2.csv,noname delimiter(",") replace
restore


/** Outputting geometric mean **/
preserve 
sort pat_id  day
keep pat_id geo_mean 
collapse (mean) geo_mean,by(pat_id)
sort pat_id 
drop pat_id 
outsheet geo_mean using data/geo_mean2matlab_v2.csv,noname delimiter(",") replace
restore

/**  Black indicator **/
preserve
sort pat_id day
keep pat_id black
collapse (mean) black,by(pat_id)
sort pat_id
drop pat_id
outsheet black using data/black2matlab_v2.csv,noname delimiter(",") replace
restore

/**  Male indicator **/
preserve
sort pat_id day
keep pat_id male
collapse (mean) male,by(pat_id)
sort pat_id
drop pat_id
outsheet male using data/male2matlab_v2.csv,noname delimiter(",") replace
restore


/**  Age group **/
preserve
sort pat_id day
keep pat_id agegrp
collapse (mean) agegrp,by(pat_id)
sort pat_id
drop pat_id
outsheet using data/age2matlab_v2.csv,noname delimiter(",") replace
restore


/** Outputting full LTCH payment **/
preserve
sort pat_id day
keep pat_id fullpayment day
collapse (max) fullpayment,by(pat_id)
sort pat_id 
drop pat_id 
outsheet fullpayment using data/fullpayment2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting aha HWH data **/
preserve
gen standalone = 1-aha_hwh
sort pat_id day
keep pat_id aha_hwh standalone day
collapse (mean) aha_hwh standalone,by(pat_id)
sort pat_id
drop pat_id
outsheet aha_hwh standalone using data/aha_hwh2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting preS data **/
preserve
sort pat_id day
keep pat_id preS day
collapse (mean) preS,by(pat_id)
sort pat_id
drop pat_id
outsheet preS using data/preS2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting LTCH MSA Count data **/
preserve
sort pat_id
keep pat_id cbsa_ltch
replace cbsa_ltch = 9999 if cbsa_ltch==.
collapse (mean) cbsa_ltch,by(pat_id)
sort pat_id
drop pat_id
outsheet cbsa_ltch using data/cbsa_ltch2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting DRG data **/
preserve
sort pat_id
keep pat_id cDRG
collapse (mean) cDRG,by(pat_id)
sort pat_id
drop pat_id
outsheet cDRG using data/cDRG2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting SSO threshold data **/
preserve
sort pat_id
keep pat_id sso_thresh
collapse (mean) sso_thresh,by(pat_id)
sort pat_id
drop pat_id
outsheet sso_thresh using data/sso_thresh2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting fyear data **/
preserve
sort pat_id
keep pat_id fyear
collapse (mean) fyear,by(pat_id)
sort pat_id
drop pat_id
outsheet fyear using data/fyear2matlab_v2.csv,noname delimiter(",") replace
restore

/** Outputting length_of_stay data **/
preserve
sort pat_id
keep pat_id length_of_stay
collapse (mean) length_of_stay,by(pat_id)
sort pat_id
drop pat_id
outsheet length_of_stay using data/LOS2matlab_v2.csv,noname delimiter(",") replace
restore

/*restore*/
/*
reg drg_price c.LOS#fyear#cDRG#numprov_msa c.LOS#(prov_fp aha_hwh ) if ///
	LOS<sso_thresh & drg_price>p5 & drg_price<p95,noconst
	
preserve
sort fyear prov_id pat_id
gen T = 45
expand T
sort pat_id LOS
by pat_id: gen day = _n
replace LOS = day
predict pay,xb
sum pay if day==1,d
restore
*/
}
/*************************************************************************
		Costs
*************************************************************************/
if `costs'==1 {

use data/MEDPAR_POS_ALL.dta
gen LOS = length_of_stay

/**Dropping 2002 observations**/
drop if fyear==2002

/**Dropping observations from 2014 and 2015**/
keep if fyear<2014

/** Generating patient id **/
gen pat_id = _n

drop if cDRG==0

/**Filling in some missing data gaps using the mode by hospital.  This is a 
	temporary fix--I'll need to find the actual data at some point.  **/
sort prov_id fyear
by prov_id: egen mode_msa = mode(prov_msa)
by prov_id: egen mode_fp  = mode(prov_fp)
by prov_id: egen mode_hwh = mode(aha_hwh)
replace prov_msa = mode_msa if prov_msa==""
replace prov_msa = mode_msa if prov_msa=="."
replace prov_fp = mode_fp if prov_fp==.
replace aha_hwh = mode_hwh if aha_hwh==.

destring(prov_id),gen(numprov_id)
destring(prov_msa),gen(numprov_msa)

/**Keeping discharges to home care or to nursing facility care**/
keep if disch_home | disch_snf | disch_othnf

/**Keeping only claims with positive Medicare payments**/
keep if drg_price>0


/********SSO Payments********/
/**Identifying observations that are in the tails of LOS distributions within
	cDRG and Year**/
	
sort LOS fyear cDRG
by LOS fyear cDRG: gen first = _n==1
by LOS fyear cDRG: egen p95 = pctile(drg_price),p(95)
by LOS fyear cDRG: egen p5  = pctile(drg_price),p(5)



/*
reg est_cov_costs c.(LOS)#fyear#cDRG c.LOS#fyear#numprov_id ///
		if LOS<sso_thresh & drg_price>p5 & drg_price<p95,noconst

preserve
sort fyear prov_id pat_id
gen T = 45
expand T
sort pat_id LOS
by pat_id: gen day = _n
replace LOS = day
predict pay,xb
sum pay if day==1,d
restore
	
*/

reg est_cov_costs c.LOS#fyear#(cDRG prov_fp##aha_hwh numprov_msa) ///
		if LOS<sso_thresh & drg_price>p5 & drg_price<p95,noconst

preserve
sort fyear cDRG prov_id pat_id
gen T = 45
expand T
sort pat_id LOS
by pat_id: gen day = _n
replace LOS = day
predict cost,xb
drop T
sum cost if day==1,d


sort pat_id day
tsset pat_id day
gen c_t = s.cost
by pat_id: replace c_t = cost if _n==1 & c_t==.
order pat_id day LOS fyear cost c_t 

drop if prov_fp==. | geo_mean==. | aha_hwh==. | black==. | agegrp==. | male==. | length_of_stay==.  

sort pat_id
replace c_t = 0 if c_t==.
save data/daily_costs.dta,replace

keep pat_id c_t day
reshape wide c_t,i(pat_id) j(day)
sort pat_id
drop pat_id
outsheet c_t1-c_t45 using data/costs2matlab_v2.csv,nonames delimiter(",") replace
restore
}
